/*
 * Samsung API
 * Copyright (c) 2009-2015 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "sample_system_info.h"

static struct network_info {
	char *description;
	char *feature_key;
} s_network_info[] = {
		{"Bluetooth",							NULL},
		{"Bluetooth",							"http://tizen.org/feature/network.bluetooth"},
		{"Handsfree Profile",					"http://tizen.org/feature/network.bluetooth.audio.call"},
		{"Advanced Audio Distribute Profile",	"http://tizen.org/feature/network.bluetooth.audio.media"},
		{"Health Device Profile",				"http://tizen.org/feature/network.bluetooth.health"},
		{"Human Input Device",					"http://tizen.org/feature/network.bluetooth.hid"},
		{"Low Energy",							"http://tizen.org/feature/network.bluetooth.le"},
		{"Object Push Profile",					"http://tizen.org/feature/network.bluetooth.opp"},
		{"NFC",									NULL},
		{"NFC",									"http://tizen.org/feature/network.nfc"},
		{"Card Readers",						"http://tizen.org/feature/network.nfc.card_emulation"},
		{"Reserved Push",						"http://tizen.org/feature/network.nfc.reserved_push"},
		{"PUSH",								NULL},
		{"IP Push Service",						"http://tizen.org/feature/network.push"},
		{"Secure",								NULL},
		{"Secure Elements",						"http://tizen.org/feature/network.secure_element"},
		{"eSe Secure Elements",					"http://tizen.org/feature/network.secure_element.ese"},
		{"UICC Secure Elements",				"http://tizen.org/feature/network.secure_element.uicc"},
		{"Telephony",							NULL},
		{"Telephony",							"http://tizen.org/feature/network.telephony"},
		{"MMS",									"http://tizen.org/feature/network.telephony.mms"},
		{"Tethering",							NULL},
		{"Tethering",							"http://tizen.org/feature/network.tethering"},
		{"Bluetooth Tethering",					"http://tizen.org/feature/network.tethering.bluetooth"},
		{"USB Tethering",						"http://tizen.org/feature/network.tethering.usb"},
		{"Wi-Fi Tethering",						"http://tizen.org/feature/network.tethering.wifi"},
		{"Wi-Fi",								NULL},
		{"Wi-Fi",								"http://tizen.org/feature/network.wifi"},
		{"Wi-Fi Direct",						"http://tizen.org/feature/network.wifi.direct"},
		{"Wi-Fi Direct Display",				"http://tizen.org/feature/network.wifi.direct.display"},
		{"Wi-Fi Direct Service Discovery",		"http://tizen.org/feature/network.wifi.direct.service_discovery"}
};

static char *_gl_text_get_cb(void *data, Evas_Object *obj, const char *part)
{
	item_data_s *id = (item_data_s *)data;
	char buf[MAX_STR] = {0,};
	int ret = -1;
	bool value = 0;

	if (!id) {
		return NULL;
	}

	if (!strcmp(part, "elm.text")) {
		return strdup(s_network_info[id->index].description);
	} else if (!strcmp(part, "elm.text.sub")) {
		ret = system_info_get_platform_bool(s_network_info[id->index].feature_key, &value);

		if (ret != SYSTEM_INFO_ERROR_NONE) {
			return NULL;
		}

		snprintf(buf, MAX_STR, "%s", value ? "Supported" : "Not Supported");
		return strdup(buf);
	}

	return NULL;
}

HAPI void network_list_cb(void *data, Evas_Object *obj, void *event_info)
{
	appdata_s *ad = (appdata_s *)data;
	Evas_Object *clist = NULL;
	Evas_Object *navi = ad->navi;
	Elm_Genlist_Item_Class *itc = elm_genlist_item_class_new();
	Elm_Genlist_Item_Class *itc2 = elm_genlist_item_class_new();
	Elm_Object_Item *item = NULL;
	Elm_Object_Item *it  = elm_list_selected_item_get(obj);
	int i;

	elm_list_item_selected_set(it, EINA_FALSE);

	if (!navi) {
		_E("[network_list_cb] navi is NULL");
		elm_genlist_item_class_free(itc);
		return;
	}

	clist = elm_genlist_add(navi);

	if (!clist) {
		_E("[network_list_cb] clist is NULL");
		elm_genlist_item_class_free(itc);
		return;
	}

	itc->item_style = "group_index";
	itc->func.content_get = NULL;
	itc->func.text_get = _gl_text_get_cb;
	itc->func.del = gc_gl_del_cb;

	itc2->item_style = "double_label";
	itc2->func.content_get = NULL;
	itc2->func.text_get = _gl_text_get_cb;
	itc2->func.del = gc_gl_del_cb;

	elm_genlist_block_count_set(clist, 14);
	elm_genlist_mode_set(clist, ELM_LIST_COMPRESS);
	evas_object_smart_callback_add(clist, "selected", gc_gl_selected_cb, NULL);

	for (i=0; i<31; i++) {
		item_data_s *id = malloc(sizeof(item_data_s));
		id->index = i;

		if (s_network_info[id->index].feature_key == NULL) {
			item = elm_genlist_item_append(clist, itc, id, NULL, ELM_GENLIST_ITEM_NONE, NULL, id);
		} else {
			item = elm_genlist_item_append(clist, itc2, id, NULL, ELM_GENLIST_ITEM_NONE, NULL, id);
		}

		id->item = item;
	}

	elm_genlist_item_class_free(itc);

	elm_naviframe_item_push(navi, "Network", NULL, NULL, clist, NULL);
}


